==> apache-druid-25.0.0-src.tar.gz: apache-druid-25.0.0-src/web-console/src/views/workbench-view/cancel-query-dialog/cancel-query-dialog.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Alert, Intent } from '@blueprintjs/core';
import React from 'react';

export interface CancelQueryDialogProps {
  onDismiss(): void;
  onCancel(): void;
}

export const CancelQueryDialog = function CancelQueryDialog(props: CancelQueryDialogProps) {
  const { onDismiss, onCancel } = props;

  return (
    <Alert
      intent={Intent.DANGER}
      isOpen
      cancelButtonText="Continue running query"
      confirmButtonText="Cancel query"
      canOutsideClickCancel
      canEscapeKeyCancel
      onCancel={onDismiss}
      onConfirm={() => {
        onCancel();
        onDismiss();
      }}
    >
      <p>Are you sure you want to cancel this query?</p>
      <p>You can&apos;t undo this action.</p>
    </Alert>
  );
};

==> apache-druid-31.0.2-src.tar.gz: apache-druid-31.0.2-src/web-console/src/views/workbench-view/cancel-query-dialog/cancel-query-dialog.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Intent } from '@blueprintjs/core';
import React from 'react';

import { AlertDialog } from '../../../dialogs';

export interface CancelQueryDialogProps {
  onDismiss(): void;
  onCancel(): void;
}

export const CancelQueryDialog = function CancelQueryDialog(props: CancelQueryDialogProps) {
  const { onDismiss, onCancel } = props;

  return (
    <AlertDialog
      intent={Intent.DANGER}
      isOpen
      cancelButtonText="Continue running query"
      confirmButtonText="Cancel query"
      canOutsideClickCancel
      canEscapeKeyCancel
      onCancel={onDismiss}
      onConfirm={() => {
        onCancel();
        onDismiss();
      }}
    >
      <p>Are you sure you want to cancel this query?</p>
      <p>You can&apos;t undo this action.</p>
    </AlertDialog>
  );
};
